methodChannel property
The method channel used to pull the current language on demand.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('keyboard_language/methods');
The method channel used to pull the current language on demand.
@visibleForTesting
final methodChannel = const MethodChannel('keyboard_language/methods');