onLanguageChanged property

Stream<String?> get onLanguageChanged

Broadcast stream of raw language tags, emitted whenever the platform reports that the active keyboard language changed.

Implementation

Stream<String?> get onLanguageChanged {
  throw UnimplementedError('onLanguageChanged has not been implemented.');
}