getCurrentLanguage method
The raw language tag reported by the platform for the active keyboard, or null if it could not be determined.
Implementation
Future<String?> getCurrentLanguage() {
throw UnimplementedError('getCurrentLanguage() has not been implemented.');
}